==> reaction-1.6.2.tgz: package/examples/lib/vanillaApp.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var reaction = require('../../index'),
    ReactDOM = reaction.ReactDOM,
    React = reaction.React;

var VanillaApp = function () {
  function VanillaApp() {
    _classCallCheck(this, VanillaApp);
  }

  _createClass(VanillaApp, null, [{
    key: 'run',
    value: function run() {
      var rootDOMElement = document.getElementById('root');

      var Comment = React.createClass({
        displayName: 'Comment',

        render: function render() {
          return React.createElement(
            'div',
            { className: 'comment' },
            React.createElement(
              'p',
              null,
              this.props.message
            )
          );
        },
        componentDidMount: function componentDidMount() {
          var message = this.props.message;

          console.log('comment mounted with message ' + message);
        },
        componentWillUnmount: function componentWillUnmount() {
          var message = this.props.message;

          console.log('comment will unmount with message ' + message);
        }
      });

      var CommentsList = React.createClass({
        displayName: 'CommentsList',

        getInitialState: function getInitialState() {
          var messages = ['Hello, world!', 'Hello world again...'],
              state = {
            messages: messages
          };

          return state;
        },
        render: function render() {
          var messages = this.state.messages;

          var comments = messages.map(function (message) {
            return React.createElement(Comment, { message: message });
          });

          return React.createElement(
            'div',
            { className: 'commentsList' },
            comments
          );
        },
        componentDidMount: function componentDidMount() {
          console.log('comments list mounted');
        }
      });

      var commentsList = React.createElement(CommentsList, null);

      ReactDOM.render(commentsList, rootDOMElement);

      setTimeout(function () {
        var messages = ['Hello world, yet again!!!'],
            state = {
          messages: messages
        };

        commentsList.setState(state);
      }, 1000); ///
    }
  }]);

  return VanillaApp;
}();

module.exports = VanillaApp;

==> reaction-1.6.21.tgz: package/examples/lib/vanillaApp.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var reaction = require('../../index'),
    ReactDOM = reaction.ReactDOM,
    React = reaction.React;

var VanillaApp = function () {
  function VanillaApp() {
    _classCallCheck(this, VanillaApp);
  }

  _createClass(VanillaApp, null, [{
    key: 'run',
    value: function run() {
      var rootDOMElement = document.getElementById('root');

      var Comment = React.createClass({
        displayName: 'Comment',

        render: function render() {
          return React.createElement(
            'div',
            { className: 'comment' },
            React.createElement(
              'p',
              null,
              this.props.message
            )
          );
        },
        componentDidMount: function componentDidMount() {
          var message = this.props.message;

          console.log('comment mounted with message ' + message);
        },
        componentWillUnmount: function componentWillUnmount() {
          var message = this.props.message;

          console.log('comment unmounted with message ' + message);
        }
      });

      var CommentsList = React.createClass({
        displayName: 'CommentsList',
        getInitialState: function getInitialState() {
          var messages = ["Hello, world!", "Hello world again..."],
              state = {
            messages: messages
          };

          return state;
        },


        render: function render() {
          var messages = this.state.messages;

          var comments = messages.map(function (message) {
            return React.createElement(Comment, { message: message });
          });

          return React.createElement(
            'div',
            { className: 'commentsList' },
            comments
          );
        },
        componentDidMount: function componentDidMount() {
          console.log('comments list mounted');
        }
      });

      var commentsList = React.createElement(CommentsList, null);

      ReactDOM.render(commentsList, rootDOMElement);

      setTimeout(function () {
        var messages = ["Hello world yet again!!!"],
            state = {
          messages: messages
        };

        commentsList.setState(state);
      }, 1000); ///
    }
  }]);

  return VanillaApp;
}();

module.exports = VanillaApp;
